#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-mail
version:              0.5.1
visibility:           public
id:                   mime-mail-0.5.1-HwCVoSiimyKcD88dBJPzs
key:                  mime-mail-0.5.1-HwCVoSiimyKcD88dBJPzs
license:              MIT
maintainer:
    Michael Snoyman <michael@snoyman.com>, Marek Suchánek <marek.suchanek@fit.cvut.cz>

author:               Michael Snoyman <michael@snoyman.com>
homepage:             http://github.com/snoyberg/mime-mail
synopsis:             Compose MIME email messages.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/mime-mail>.

category:             Email
abi:                  7d3d4ab007a21d99a0e6e08eb4da1ed4
exposed:              True
exposed-modules:      Network.Mail.Mime
import-dirs:          /usr/lib/ghc-8.10.5/site-local/mime-mail-0.5.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mime-mail-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mime-mail-0.5.1
hs-libraries:         HSmime-mail-0.5.1-HwCVoSiimyKcD88dBJPzs
depends:
    base-4.14.2.0 base64-bytestring-1.2.0.1-9folcSD81CwJ7ibR6pZE7R
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    filepath-1.4.2.1 process-1.6.9.0
    random-1.2.0-GZbCBA9NAlUBaVRSIi1HYu text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-mime-mail/html/mime-mail.haddock
haddock-html:         /usr/share/doc/haskell-mime-mail/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

